@@ -1,7 +1,7 @@
 package Git::CPAN::Patch::Command::Import;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Import a module into a git repository
-$Git::CPAN::Patch::Command::Import::VERSION = '2.3.0';
+$Git::CPAN::Patch::Command::Import::VERSION = '2.3.1';
 use 5.10.0;
 
 use strict;
@@ -22,9 +22,14 @@ use MooseX::App::Command;
 extends 'Git::CPAN::Patch';
 with 'Git::CPAN::Patch::Role::Git';
 
-with 'MooseX::Role::Tempdir' => {
-    tmpdir_opts => { CLEANUP => 1 },
-};
+has tmpdir => (
+  is => 'ro',
+  isa => 'Path::Tiny',
+  lazy => 1,
+  default => sub {
+    return Path::Tiny->tempdir();
+  }
+);
 
 use experimental qw(smartmatch);
 
@@ -89,7 +94,7 @@ method get_releases_from_url($url) {
 
     say "copying '$url' to '$destination'";
 
-    LWP::Simple::mirror( $url => $destination ) 
+    LWP::Simple::mirror( $url => $destination )
         or die "Failed to mirror $url\n";
 
     return Git::CPAN::Patch::Release->new(
@@ -286,7 +291,7 @@ Git::CPAN::Patch::Command::Import - Import a module into a git repository
 
 =head1 VERSION
 
-version 2.3.0
+version 2.3.1
 
 =head1 SYNOPSIS
 
@@ -370,7 +375,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Yanick Champoux.
+This software is copyright (c) 2017 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
