@@ -1,6 +1,6 @@
 package Git::CPAN::Patch::Release;
 our $AUTHORITY = 'cpan:YANICK';
-$Git::CPAN::Patch::Release::VERSION = '2.3.0';
+$Git::CPAN::Patch::Release::VERSION = '2.3.1';
 use strict;
 use warnings;
 use Method::Signatures::Simple;
@@ -12,9 +12,14 @@ use version;
 
 use Moose;
 
-with 'MooseX::Role::Tempdir' => {
-    tmpdir_opts => { CLEANUP => 1 },
-};
+has tmpdir => (
+  is => 'ro',
+  isa => 'Path::Tiny',
+  lazy => 1,
+  default => sub {
+    return Path::Tiny->tempdir();
+  }
+);
 
 has author_name => (
     is => 'ro',
@@ -230,7 +235,7 @@ Git::CPAN::Patch::Release
 
 =head1 VERSION
 
-version 2.3.0
+version 2.3.1
 
 =head1 AUTHOR
 
@@ -238,7 +243,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Yanick Champoux.
+This software is copyright (c) 2017 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
